@@ -1,10 +1,10 @@
-import six  # TODO Remove this along with GeoJsonDict when support for python 2.6/2.7 is dropped.
 import json
 from collections import OrderedDict
 
 from django.contrib.gis.geos import GEOSGeometry, GEOSException
 from django.contrib.gis.gdal import GDALException
 from django.core.exceptions import ValidationError
+from django.utils import six  # TODO Remove this along with GeoJsonDict when support for python 2.6/2.7 is dropped.
 from django.utils.translation import ugettext_lazy as _
 from rest_framework.fields import Field, SerializerMethodField
 
